==> GOstats_2.16.0.zip: GOstats/doc/GOstatsHyperG.R <==
###################################################
### chunk number 1: Setup
###################################################
#line 61 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
library("ALL")
library("hgu95av2.db")
library("GO.db")
library("annotate")
library("genefilter")
library("GOstats")
library("RColorBrewer")
library("xtable")
library("Rgraphviz")


###################################################
### chunk number 2: universeSizeVsPvalue
###################################################
#line 102 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
hg_tester <- function(size) {
    numFound <- 10
    numDrawn <- 400
    numAtCat <- 40
    numNotAtCat <- size - numAtCat
    phyper(numFound-1, numAtCat, numNotAtCat, numDrawn, lower.tail=FALSE)
}
pv1000 <- hg_tester(1000)
pv5000 <- hg_tester(5000)


###################################################
### chunk number 3: bcrAblOrNegSubset
###################################################
#line 132 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
data(ALL, package="ALL")
## For this data we can have ALL1/AF4 or BCR/ABL
subsetType <- "ALL1/AF4"

## Subset of interest: 37BRC/ABL + 42NEG = 79 samples
Bcell <- grep("^B", as.character(ALL$BT))
bcrAblOrNegIdx <- which(as.character(ALL$mol) %in% c("NEG", subsetType))

bcrAblOrNeg <- ALL[, intersect(Bcell, bcrAblOrNegIdx)]
bcrAblOrNeg$mol.biol = factor(bcrAblOrNeg$mol.biol)


###################################################
### chunk number 4: nsFiltering-noEntrez
###################################################
#line 148 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
## Remove genes that have no entrezGene id
entrezIds <- mget(featureNames(bcrAblOrNeg), envir=hgu95av2ENTREZID)
haveEntrezId <- names(entrezIds)[sapply(entrezIds, function(x) !is.na(x))]
numNoEntrezId <- length(featureNames(bcrAblOrNeg)) - length(haveEntrezId)
bcrAblOrNeg <- bcrAblOrNeg[haveEntrezId, ]


###################################################
### chunk number 5: nsFiltering-noGO
###################################################
#line 158 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
## Remove genes with no GO mapping
haveGo <- sapply(mget(featureNames(bcrAblOrNeg), hgu95av2GO),
                 function(x) {
                     if (length(x) == 1 && is.na(x)) 
                       FALSE 
                     else TRUE
                 })
numNoGO <- sum(!haveGo)
bcrAblOrNeg <- bcrAblOrNeg[haveGo, ]


###################################################
### chunk number 6: nsFiltering-IQR
###################################################
#line 175 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
## Non-specific filtering based on IQR
iqrCutoff <- 0.5
bcrAblOrNegIqr <- apply(exprs(bcrAblOrNeg), 1, IQR)
selected <- bcrAblOrNegIqr > iqrCutoff

## Drop those that are on the Y chromosome
## because there is an imbalance of men and women by group
chrN <- mget(featureNames(bcrAblOrNeg), envir=hgu95av2CHR)
onY <- sapply(chrN, function(x) any(x=="Y"))
onY[is.na(onY)] <- FALSE
selected <- selected & !onY

nsFiltered <- bcrAblOrNeg[selected, ]


###################################################
### chunk number 7: nsFiltering-unique
###################################################
#line 195 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
numNsWithDups <- length(featureNames(nsFiltered))
nsFilteredIqr <- bcrAblOrNegIqr[selected]
uniqGenes <- findLargest(featureNames(nsFiltered), nsFilteredIqr, 
                         "hgu95av2")
nsFiltered <- nsFiltered[uniqGenes, ]
numSelected <- length(featureNames(nsFiltered))

##set up some colors
BCRcols = ifelse(nsFiltered$mol == subsetType, "goldenrod", "skyblue")
cols = brewer.pal(10, "RdBu")


###################################################
### chunk number 8: defineGeneUniverse
###################################################
#line 211 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
## Define gene universe based on results of non-specific filtering
affyUniverse <- featureNames(nsFiltered)
entrezUniverse <- unlist(mget(affyUniverse, hgu95av2ENTREZID))
if (any(duplicated(entrezUniverse)))
  stop("error in gene universe: can't have duplicate Entrez Gene Ids")

## Also define an alternate universe based on the entire chip
chipAffyUniverse <- featureNames(bcrAblOrNeg)
chipEntrezUniverse <- mget(chipAffyUniverse, hgu95av2ENTREZID)
chipEntrezUniverse <- unique(unlist(chipEntrezUniverse)) 


###################################################
### chunk number 9: parametric1
###################################################
#line 247 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
ttestCutoff <- 0.05
ttests = rowttests(nsFiltered, "mol.biol")

smPV = ttests$p.value < ttestCutoff

pvalFiltered <- nsFiltered[smPV, ]
selectedEntrezIds <- unlist(mget(featureNames(pvalFiltered),
                                 hgu95av2ENTREZID))


###################################################
### chunk number 10: withYourData1 eval=FALSE
###################################################
## #line 314 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
## entrezUniverse <- unlist(mget(featureNames(yourData), 
##                               hgu95av2ENTREZID))
## if (any(duplicated(entrezUniverse)))
##   stop("error in gene universe: can't have duplicate Entrez Gene Ids")
## 
## pvalFiltered <- yourData[hasSmallPvalue, ]
## selectedEntrezIds <- unlist(mget(featureNames(pvalFiltered),
##                                  hgu95av2ENTREZID))


###################################################
### chunk number 11: standardHyperGeo
###################################################
#line 379 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
hgCutoff <- 0.001
params <- new("GOHyperGParams",
              geneIds=selectedEntrezIds,
              universeGeneIds=entrezUniverse,
              annotation="hgu95av2.db",
              ontology="BP",
              pvalueCutoff=hgCutoff,
              conditional=FALSE,
              testDirection="over")



###################################################
### chunk number 12: condHyperGeo
###################################################
#line 396 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
paramsCond <- params
conditional(paramsCond) <- TRUE


###################################################
### chunk number 13: standardHGTEST
###################################################
#line 424 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
hgOver <- hyperGTest(params)
hgCondOver <- hyperGTest(paramsCond)



###################################################
### chunk number 14: HGTestAns
###################################################
#line 432 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
hgOver
hgCondOver


###################################################
### chunk number 15: summaryEx
###################################################
#line 448 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
df <- summary(hgOver)
names(df)                               # the columns
dim(summary(hgOver, pvalue=0.1))
dim(summary(hgOver, categorySize=10))


###################################################
### chunk number 16: resultAccessors
###################################################
#line 459 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
pvalues(hgOver)[1:3]

oddsRatios(hgOver)[1:3]

expectedCounts(hgOver)[1:3]

geneCounts(hgOver)[1:3]
universeCounts(hgOver)[1:3]

length(geneIds(hgOver))
length(geneIdUniverse(hgOver)[[3]])

## GOHyperGResult _only_
## (NB: edges go from parent to child)
goDag(hgOver)

geneMappedCount(hgOver)
universeMappedCount(hgOver)

conditional(hgOver)
testDirection(hgOver)
testName(hgOver)



###################################################
### chunk number 17: htmlReportExample
###################################################
#line 491 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
htmlReport(hgCondOver, file="ALL_hgco.html")


###################################################
### chunk number 18: helperFunc
###################################################
#line 497 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
sigCategories <- function(res, p) {
    if (missing(p))
      p <- pvalueCutoff(res)
    pv <- pvalues(res)
    goIds <- names(pv[pv < p])
    goIds
}


###################################################
### chunk number 19: plotFuns
###################################################
#line 507 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
coloredGoPlot <- function(ccMaxGraph, hgOver, hgCondOver) {
    nodeColors <- sapply(nodes(ccMaxGraph),
                         function(n) {
                             if (n %in% sigCategories(hgCondOver))
                               "dark red"
                             else if (n %in% sigCategories(hgOver))
                               "pink"
                             else 
                               "gray"
                         })
    nattr <- makeNodeAttrs(ccMaxGraph,
                           label=nodes(ccMaxGraph),
                           shape="ellipse",
                           fillcolor=nodeColors,
                           fixedsize=FALSE)
    plot(ccMaxGraph, nodeAttrs=nattr)
}

getMaxConnCompGraph <- function(hgOver, hgCondOver) {
    ##uGoDagRev <- ugraph(goDag(hgOver))
    sigNodes <- sigCategories(hgOver)
    ##adjNodes <- unlist(adj(uGoDagRev, sigNodes))
    adjNodes <- unlist(adj(goDag(hgOver), sigNodes))
    displayNodes <- unique(c(sigNodes, adjNodes))
    displayGraph <- subGraph(displayNodes, goDag(hgOver))
    cc <- connComp(displayGraph)
    ccSizes <- listLen(cc)
    ccMaxIdx <- which(ccSizes == max(ccSizes))
    ccMaxGraph <- subGraph(cc[[ccMaxIdx]], displayGraph)
    ccMaxGraph 
}



###################################################
### chunk number 20: info
###################################################
#line 572 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpqBCeOg/R.INSTALL76b37517/GOstats/inst/doc/GOstatsHyperG.Rnw"
toLatex(sessionInfo())

==> GOstats_2.18.0.zip: GOstats/doc/GOstatsHyperG.R <==
###################################################
### chunk number 1: Setup
###################################################
#line 61 "GOstatsHyperG.Rnw"
library("ALL")
library("hgu95av2.db")
library("GO.db")
library("annotate")
library("genefilter")
library("GOstats")
library("RColorBrewer")
library("xtable")
library("Rgraphviz")


###################################################
### chunk number 2: universeSizeVsPvalue
###################################################
#line 102 "GOstatsHyperG.Rnw"
hg_tester <- function(size) {
    numFound <- 10
    numDrawn <- 400
    numAtCat <- 40
    numNotAtCat <- size - numAtCat
    phyper(numFound-1, numAtCat, numNotAtCat, numDrawn, lower.tail=FALSE)
}
pv1000 <- hg_tester(1000)
pv5000 <- hg_tester(5000)


###################################################
### chunk number 3: bcrAblOrNegSubset
###################################################
#line 132 "GOstatsHyperG.Rnw"
data(ALL, package="ALL")
## For this data we can have ALL1/AF4 or BCR/ABL
subsetType <- "ALL1/AF4"

## Subset of interest: 37BRC/ABL + 42NEG = 79 samples
Bcell <- grep("^B", as.character(ALL$BT))
bcrAblOrNegIdx <- which(as.character(ALL$mol) %in% c("NEG", subsetType))

bcrAblOrNeg <- ALL[, intersect(Bcell, bcrAblOrNegIdx)]
bcrAblOrNeg$mol.biol = factor(bcrAblOrNeg$mol.biol)


###################################################
### chunk number 4: nsFiltering-noEntrez
###################################################
#line 148 "GOstatsHyperG.Rnw"
## Remove genes that have no entrezGene id
entrezIds <- mget(featureNames(bcrAblOrNeg), envir=hgu95av2ENTREZID)
haveEntrezId <- names(entrezIds)[sapply(entrezIds, function(x) !is.na(x))]
numNoEntrezId <- length(featureNames(bcrAblOrNeg)) - length(haveEntrezId)
bcrAblOrNeg <- bcrAblOrNeg[haveEntrezId, ]


###################################################
### chunk number 5: nsFiltering-noGO
###################################################
#line 158 "GOstatsHyperG.Rnw"
## Remove genes with no GO mapping
haveGo <- sapply(mget(featureNames(bcrAblOrNeg), hgu95av2GO),
                 function(x) {
                     if (length(x) == 1 && is.na(x)) 
                       FALSE 
                     else TRUE
                 })
numNoGO <- sum(!haveGo)
bcrAblOrNeg <- bcrAblOrNeg[haveGo, ]


###################################################
### chunk number 6: nsFiltering-IQR
###################################################
#line 175 "GOstatsHyperG.Rnw"
## Non-specific filtering based on IQR
iqrCutoff <- 0.5
bcrAblOrNegIqr <- apply(exprs(bcrAblOrNeg), 1, IQR)
selected <- bcrAblOrNegIqr > iqrCutoff

## Drop those that are on the Y chromosome
## because there is an imbalance of men and women by group
chrN <- mget(featureNames(bcrAblOrNeg), envir=hgu95av2CHR)
onY <- sapply(chrN, function(x) any(x=="Y"))
onY[is.na(onY)] <- FALSE
selected <- selected & !onY

nsFiltered <- bcrAblOrNeg[selected, ]


###################################################
### chunk number 7: nsFiltering-unique
###################################################
#line 195 "GOstatsHyperG.Rnw"
numNsWithDups <- length(featureNames(nsFiltered))
nsFilteredIqr <- bcrAblOrNegIqr[selected]
uniqGenes <- findLargest(featureNames(nsFiltered), nsFilteredIqr, 
                         "hgu95av2")
nsFiltered <- nsFiltered[uniqGenes, ]
numSelected <- length(featureNames(nsFiltered))

##set up some colors
BCRcols = ifelse(nsFiltered$mol == subsetType, "goldenrod", "skyblue")
cols = brewer.pal(10, "RdBu")


###################################################
### chunk number 8: defineGeneUniverse
###################################################
#line 211 "GOstatsHyperG.Rnw"
## Define gene universe based on results of non-specific filtering
affyUniverse <- featureNames(nsFiltered)
entrezUniverse <- unlist(mget(affyUniverse, hgu95av2ENTREZID))
if (any(duplicated(entrezUniverse)))
  stop("error in gene universe: can't have duplicate Entrez Gene Ids")

## Also define an alternate universe based on the entire chip
chipAffyUniverse <- featureNames(bcrAblOrNeg)
chipEntrezUniverse <- mget(chipAffyUniverse, hgu95av2ENTREZID)
chipEntrezUniverse <- unique(unlist(chipEntrezUniverse)) 


###################################################
### chunk number 9: parametric1
###################################################
#line 247 "GOstatsHyperG.Rnw"
ttestCutoff <- 0.05
ttests = rowttests(nsFiltered, "mol.biol")

smPV = ttests$p.value < ttestCutoff

pvalFiltered <- nsFiltered[smPV, ]
selectedEntrezIds <- unlist(mget(featureNames(pvalFiltered),
                                 hgu95av2ENTREZID))


###################################################
### chunk number 10: withYourData1 eval=FALSE
###################################################
## #line 314 "GOstatsHyperG.Rnw"
## entrezUniverse <- unlist(mget(featureNames(yourData), 
##                               hgu95av2ENTREZID))
## if (any(duplicated(entrezUniverse)))
##   stop("error in gene universe: can't have duplicate Entrez Gene Ids")
## 
## pvalFiltered <- yourData[hasSmallPvalue, ]
## selectedEntrezIds <- unlist(mget(featureNames(pvalFiltered),
##                                  hgu95av2ENTREZID))


###################################################
### chunk number 11: standardHyperGeo
###################################################
#line 379 "GOstatsHyperG.Rnw"
hgCutoff <- 0.001
params <- new("GOHyperGParams",
              geneIds=selectedEntrezIds,
              universeGeneIds=entrezUniverse,
              annotation="hgu95av2.db",
              ontology="BP",
              pvalueCutoff=hgCutoff,
              conditional=FALSE,
              testDirection="over")



###################################################
### chunk number 12: condHyperGeo
###################################################
#line 396 "GOstatsHyperG.Rnw"
paramsCond <- params
conditional(paramsCond) <- TRUE


###################################################
### chunk number 13: standardHGTEST
###################################################
#line 424 "GOstatsHyperG.Rnw"
hgOver <- hyperGTest(params)
hgCondOver <- hyperGTest(paramsCond)



###################################################
### chunk number 14: HGTestAns
###################################################
#line 432 "GOstatsHyperG.Rnw"
hgOver
hgCondOver


###################################################
### chunk number 15: summaryEx
###################################################
#line 448 "GOstatsHyperG.Rnw"
df <- summary(hgOver)
names(df)                               # the columns
dim(summary(hgOver, pvalue=0.1))
dim(summary(hgOver, categorySize=10))


###################################################
### chunk number 16: resultAccessors
###################################################
#line 459 "GOstatsHyperG.Rnw"
pvalues(hgOver)[1:3]

oddsRatios(hgOver)[1:3]

expectedCounts(hgOver)[1:3]

geneCounts(hgOver)[1:3]
universeCounts(hgOver)[1:3]

length(geneIds(hgOver))
length(geneIdUniverse(hgOver)[[3]])

## GOHyperGResult _only_
## (NB: edges go from parent to child)
goDag(hgOver)

geneMappedCount(hgOver)
universeMappedCount(hgOver)

conditional(hgOver)
testDirection(hgOver)
testName(hgOver)



###################################################
### chunk number 17: htmlReportExample
###################################################
#line 491 "GOstatsHyperG.Rnw"
htmlReport(hgCondOver, file="ALL_hgco.html")


###################################################
### chunk number 18: helperFunc
###################################################
#line 497 "GOstatsHyperG.Rnw"
sigCategories <- function(res, p) {
    if (missing(p))
      p <- pvalueCutoff(res)
    pv <- pvalues(res)
    goIds <- names(pv[pv < p])
    goIds
}


###################################################
### chunk number 19: plotFuns
###################################################
#line 507 "GOstatsHyperG.Rnw"
coloredGoPlot <- function(ccMaxGraph, hgOver, hgCondOver) {
    nodeColors <- sapply(nodes(ccMaxGraph),
                         function(n) {
                             if (n %in% sigCategories(hgCondOver))
                               "dark red"
                             else if (n %in% sigCategories(hgOver))
                               "pink"
                             else 
                               "gray"
                         })
    nattr <- makeNodeAttrs(ccMaxGraph,
                           label=nodes(ccMaxGraph),
                           shape="ellipse",
                           fillcolor=nodeColors,
                           fixedsize=FALSE)
    plot(ccMaxGraph, nodeAttrs=nattr)
}

getMaxConnCompGraph <- function(hgOver, hgCondOver) {
    ##uGoDagRev <- ugraph(goDag(hgOver))
    sigNodes <- sigCategories(hgOver)
    ##adjNodes <- unlist(adj(uGoDagRev, sigNodes))
    adjNodes <- unlist(adj(goDag(hgOver), sigNodes))
    displayNodes <- unique(c(sigNodes, adjNodes))
    displayGraph <- subGraph(displayNodes, goDag(hgOver))
    cc <- connComp(displayGraph)
    ccSizes <- listLen(cc)
    ccMaxIdx <- which(ccSizes == max(ccSizes))
    ccMaxGraph <- subGraph(cc[[ccMaxIdx]], displayGraph)
    ccMaxGraph 
}



###################################################
### chunk number 20: info
###################################################
#line 572 "GOstatsHyperG.Rnw"
toLatex(sessionInfo())
